@@ -2,7 +2,7 @@
 Market impact access module.
 """
 from .contract import Contract
-from ..data.constants import FUTURES
+from ..data.constants import get_futures
 
 DEFAULT_SPREAD = 5e-4
 
@@ -20,7 +20,8 @@ class MarketImpact:
         Where we will implement the computation of an estimate of the market impact.
         """
 
-    def get(self, ticker=None, ric=None):
+    @staticmethod
+    def get(ticker=None, ric=None):
         """
         Get the market impact for the instrument.
 
@@ -39,4 +40,4 @@ class MarketImpact:
         """
         if ticker is None:
             ticker = Contract(ric=ric).ticker
-        return FUTURES.get(ticker, {}).get("Spread", DEFAULT_SPREAD)
+        return get_futures().get(ticker, {}).get("Spread", DEFAULT_SPREAD)
