@@ -1,10 +1,12 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+"""
+Bar event module.
+"""
 import pandas as pd
-from ..event.event import *
+from ..event.event import Event, EventType
 
 
 class BarEvent(Event):
+    # pylint: disable=too-many-instance-attributes
     """
     Bar event, aggregated from TickEvent
     """
@@ -25,24 +27,16 @@ class BarEvent(Event):
         self.volume = 0
 
     def bar_end_time(self):
+        """
+        Bar end time.
+        """
         # To be consistent with (daily) bar backtest, bar_end_time is set to be bar_start_time
         return self.bar_start_time
         # return self.bar_start_time + pd.Timedelta(seconds=self.interval)
 
     def __str__(self):
         return (
-            "Time: %s, Symbol: %s, Interval: %s, "
-            "Open: %s, High: %s, Low: %s, Close: %s, "
-            "Adj Close: %s, Volume: %s"
-            % (
-                str(self.bar_start_time),
-                str(self.full_symbol),
-                str(self.interval),
-                str(self.open_price),
-                str(self.high_price),
-                str(self.low_price),
-                str(self.close_price),
-                str(self.adj_close_price),
-                str(self.volume),
-            )
+            f"Time: {self.bar_start_time}, Symbol: {self.full_symbol}, Interval: {self.interval}, "
+            f"Open: {self.open_price}, High: {self.high_price}, Low: {self.low_price}, "
+            f"Close: {self.close_price}, Adj Close: {self.adj_close_price}, Volume: {self.volume}"
         )
