@@ -1,7 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 from .fill_event import *
-from .order_type import *
 from .order_flag import *
 from .order_manager import *
 from .order_status import *
