@@ -1,12 +1,13 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-from ..event.event import *
+"""
+Position event.
+"""
+from ..event.event import Event, EventType
 from .position import Position
 
 
 class PositionEvent(Event):
     """
-    position event directly from live broker
+    Position event directly from live broker.
     """
 
     def __init__(self):
@@ -15,7 +16,7 @@ class PositionEvent(Event):
         """
         self.event_type = EventType.POSITION
         self.full_symbol = ""
-        self_sec_type = ""
+        self_sec_type = ""  # pylint: disable=unused-variable
         self.average_cost = 0.0
         self.size = 0
         self.pre_size = 0
@@ -26,6 +27,9 @@ class PositionEvent(Event):
         self.timestamp = ""
 
     def to_position(self):
+        """
+        To position.
+        """
         pos = Position(self.full_symbol, self.average_cost, self.size)
         pos.realized_pnl = self.realized_pnl
         pos.unrealized_pnl = self.unrealized_pnl
@@ -34,10 +38,7 @@ class PositionEvent(Event):
         return pos
 
     def __str__(self):
-        return "Ticker: %s, Cost: %s, Size: %s, opl: %s, rpl: %s" % (
-            str(self.full_symbol),
-            str(self.average_cost),
-            str(self.size),
-            str(self.unrealized_pnl),
-            str(self.realized_pnl),
+        return (
+            f"Ticker: {self.full_symbol}, Cost: {self.average_cost}, "
+            f"Size: {self.size}, opl: {self.unrealized_pnl}, rpl: {self.realized_pnl}"
         )
